summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browsing_data_remover.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/browsing_data_remover.h')
-rw-r--r--chrome/browser/browsing_data_remover.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/browsing_data_remover.h b/chrome/browser/browsing_data_remover.h
index b54ef03..a2459d1c 100644
--- a/chrome/browser/browsing_data_remover.h
+++ b/chrome/browser/browsing_data_remover.h
@@ -246,9 +246,9 @@ class BrowsingDataRemover : public content::NotificationObserver,
// Calculate the begin time for the deletion range specified by |time_period|.
base::Time CalculateBeginDeleteTime(TimePeriod time_period);
- // Invoked on the WEBKIT thread to clear local storage.
- void ClearDOMStorageOnWebKitThread(
- scoped_refptr<content::DOMStorageContext> dom_storage_context);
+ // Invoked in a background task to clear local storage.
+ void ClearDOMStorageInSequencedTask(
+ content::DOMStorageContext* dom_storage_context);
// Returns true if we're all done.
bool all_done() {